import os
import xml.etree.ElementTree as ET
from datetime import datetime
from xml.dom import minidom

def prettify_xml(elem):
    """Return a pretty-printed XML string for the Element."""
    rough_string = ET.tostring(elem, 'utf-8')
    reparsed = minidom.parseString(rough_string)
    return reparsed.toprettyxml(indent="  ")

def create_combined_sitemap(brands):
    urlset = ET.Element("urlset", xmlns="http://www.sitemaps.org/schemas/sitemap/0.9")
    
    for brand in brands:
        url = f"https://indosoccer.id/{brand}"
        url_element = ET.SubElement(urlset, "url")
        loc = ET.SubElement(url_element, "loc")
        loc.text = url
        lastmod = ET.SubElement(url_element, "lastmod")
        lastmod.text = datetime.now().strftime("%Y-%m-%d")
        changefreq = ET.SubElement(url_element, "changefreq")
        changefreq.text = "daily"
        priority = ET.SubElement(url_element, "priority")
        priority.text = "0.8"

    pretty_xml_as_string = prettify_xml(urlset)
    sitemap_file = "sitemap.xml"
    with open(sitemap_file, "w") as f:
        f.write(pretty_xml_as_string)
    return sitemap_file

def read_brands(file_path):
    with open(file_path, 'r') as file:
        brands = file.read().splitlines()
    return brands

def main():
    brand_file = "data.txt"
    if not os.path.exists(brand_file):
        print(f"File {brand_file} tidak ditemukan.")
        return

    brands = read_brands(brand_file)
    sitemap_file = create_combined_sitemap(brands)
    print(f"Sitemap gabungan dibuat: {sitemap_file}")

if __name__ == "__main__":
    main()
